@@ -140,20 +140,6 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
     if (output==1) cat("Imputation number ", i, "registered", "\n")
   }
   
-  betapostmean<-apply(betapost, c(1,2), mean)
-  upostmean<-apply(upostall, c(1,2), mean)
-  omegapostmean<-apply(omegapost, c(1,2), mean)
-  covupostmean<-apply(covupost, c(1,2), mean)
-  if (output==1) {
-    cat("The posterior mean of the fixed effects estimates is:\n")
-    print(betapostmean)
-    cat("The posterior mean of the random effects estimates is:\n")
-    print(upostmean)
-    cat("The posterior mean of the level 1 covariance matrices is:\n")
-    print(omegapostmean)
-    cat("The posterior mean of the level 2 covariance matrix is:\n")
-    print(covupostmean)
-  }
   imp<-data.frame(imp)
   for (i in 1:ncol(Y.cat)) {
     imp[,(ncol(Y.con)+i)]<-as.factor(imp[,(ncol(Y.con)+i)]) 
@@ -174,5 +160,37 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
   if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
   if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")  
   colnames(imp)<-c(colnamycon,colnamycat,colnamx,colnamz,"clus","id","Imputation")
+  cnycatcomp<-rep(NA,(sum(Y.numcat)-length(Y.numcat)))
+  count=0
+  for ( j in 1:ncol(Y.cat)) {
+    for (k in 1:(Y.numcat[j]-1)) {
+      cnycatcomp[count+k]<-paste(colnamycat[j],k,sep=".")
+    }
+    count=count+Y.numcat[j]-1
+  }
+  cnamycomp<-c(colnamycon,cnycatcomp)
+  dimnames(betapost)[1] <- list(colnamx)
+  dimnames(betapost)[2] <- list(cnamycomp)
+  dimnames(omegapost)[1] <- list(paste(cnamycomp,rep(levels(clus),each=ncol(Yimp2)), sep="."))
+  dimnames(omegapost)[2] <- list(cnamycomp)
+  colnamcovu<-paste(cnamycomp,rep(colnamz,each=ncol(omegapost)),sep="*")
+  dimnames(covupost)[1] <- list(colnamcovu)
+  dimnames(covupost)[2] <- list(colnamcovu)
+  dimnames(upostall)[1]<-list(levels(clus))
+  dimnames(upostall)[2]<-list(colnamcovu)
+  betapostmean<-data.frame(apply(betapost, c(1,2), mean))    
+  upostmean<-data.frame(apply(upostall, c(1,2), mean))
+  omegapostmean<-data.frame(apply(omegapost, c(1,2), mean))
+  covupostmean<-data.frame(apply(covupost, c(1,2), mean))
+  if (output==1) {
+    cat("The posterior mean of the fixed effects estimates is:\n")
+    print(t(betapostmean))
+    cat("\nThe posterior mean of the random effects estimates is:\n")
+    print(upostmean)
+    cat("\nThe posterior mean of the level 1 covariance matrices is:\n")
+    print(omegapostmean)
+    cat("\nThe posterior mean of the level 2 covariance matrix is:\n")
+    print(covupostmean)
+  }
   return(imp)
 }
