@@ -886,8 +886,9 @@ for (i=0;i<ns;i++) {
 		}
 	}
 	
-	if ((i+1)%fl==0) Rprintf("Iteration %d completed\n",i+1);
+	if ((i+1)%fl==0) Rprintf(".");
 }
+if (fl==1) Rprintf("\n");
 
 if (((double)accratio/((double)totprop))<0.3) Rprintf("Warning: acceptance ratio = %f. This might be a sign that the chain did not mix well. \n" , ((double)accratio/((double)totprop)));
 
